/* SPDX-License-Identifier: GPL-2.0-or-later */

#ifndef VARIANT_GPIO_H
#define VARIANT_GPIO_H

#include <baseboard/gpio.h>

#define WWAN_FCPO	GPP_H23
#define WWAN_RST	GPP_F12
#define WWAN_PERST	GPP_F13
#define T1_OFF_MS	20
#define T2_OFF_MS	10
#define T0_OFF_MS	150

#endif
